/*
Profile Settings
*/

/********************************************************************************
** Form generated from reading UI file 'SettingsDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSDIALOG_H
#define UI_SETTINGSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SettingsDialog
{
public:
    QGridLayout *gridLayout_2;
    QFrame *frame3;
    QCheckBox *mediaNeedsChange;
    QLabel *label_4;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *numBackups;
    QLabel *label_2;
    QSpinBox *fullBackupInterval;
    QLabel *textLabel1;
    QLineEdit *filter;
    QGroupBox *groupBox2;
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QComboBox *predefSizes;
    QSpinBox *maxSliceSize;
    QLabel *label_3;
    QPlainTextEdit *dirFilter;
    QCheckBox *compressFiles;
    QLineEdit *prefix;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SettingsDialog)
    {
        if (SettingsDialog->objectName().isEmpty())
            SettingsDialog->setObjectName("SettingsDialog");
        SettingsDialog->resize(350, 525);
        gridLayout_2 = new QGridLayout(SettingsDialog);
        gridLayout_2->setSpacing(6);
        gridLayout_2->setContentsMargins(11, 11, 11, 11);
        gridLayout_2->setObjectName("gridLayout_2");
        frame3 = new QFrame(SettingsDialog);
        frame3->setObjectName("frame3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(frame3->sizePolicy().hasHeightForWidth());
        frame3->setSizePolicy(sizePolicy);
        frame3->setFrameShape(QFrame::HLine);
        frame3->setFrameShadow(QFrame::Sunken);

        gridLayout_2->addWidget(frame3, 10, 0, 1, 1);

        mediaNeedsChange = new QCheckBox(SettingsDialog);
        mediaNeedsChange->setObjectName("mediaNeedsChange");

        gridLayout_2->addWidget(mediaNeedsChange, 8, 0, 1, 1);

        label_4 = new QLabel(SettingsDialog);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 6, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(SettingsDialog);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        numBackups = new QSpinBox(SettingsDialog);
        numBackups->setObjectName("numBackups");
        numBackups->setMaximum(1000);

        gridLayout->addWidget(numBackups, 0, 2, 1, 1);

        label_2 = new QLabel(SettingsDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        fullBackupInterval = new QSpinBox(SettingsDialog);
        fullBackupInterval->setObjectName("fullBackupInterval");
        fullBackupInterval->setMinimum(1);
        fullBackupInterval->setMaximum(500);

        gridLayout->addWidget(fullBackupInterval, 1, 2, 1, 1);


        gridLayout_2->addLayout(gridLayout, 3, 0, 1, 1);

        textLabel1 = new QLabel(SettingsDialog);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        gridLayout_2->addWidget(textLabel1, 0, 0, 1, 1);

        filter = new QLineEdit(SettingsDialog);
        filter->setObjectName("filter");

        gridLayout_2->addWidget(filter, 5, 0, 1, 1);

        groupBox2 = new QGroupBox(SettingsDialog);
        groupBox2->setObjectName("groupBox2");
        vboxLayout = new QVBoxLayout(groupBox2);
        vboxLayout->setSpacing(6);
        vboxLayout->setContentsMargins(11, 11, 11, 11);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        predefSizes = new QComboBox(groupBox2);
        predefSizes->setObjectName("predefSizes");

        hboxLayout->addWidget(predefSizes);

        maxSliceSize = new QSpinBox(groupBox2);
        maxSliceSize->setObjectName("maxSliceSize");
        maxSliceSize->setEnabled(true);
        maxSliceSize->setMinimum(0);
        maxSliceSize->setMaximum(999999);

        hboxLayout->addWidget(maxSliceSize);


        vboxLayout->addLayout(hboxLayout);


        gridLayout_2->addWidget(groupBox2, 2, 0, 1, 1);

        label_3 = new QLabel(SettingsDialog);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 4, 0, 1, 1);

        dirFilter = new QPlainTextEdit(SettingsDialog);
        dirFilter->setObjectName("dirFilter");

        gridLayout_2->addWidget(dirFilter, 7, 0, 1, 1);

        compressFiles = new QCheckBox(SettingsDialog);
        compressFiles->setObjectName("compressFiles");

        gridLayout_2->addWidget(compressFiles, 9, 0, 1, 1);

        prefix = new QLineEdit(SettingsDialog);
        prefix->setObjectName("prefix");

        gridLayout_2->addWidget(prefix, 1, 0, 1, 1);

        buttonBox = new QDialogButtonBox(SettingsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout_2->addWidget(buttonBox, 11, 0, 1, 1);


        retranslateUi(SettingsDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SettingsDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SettingsDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SettingsDialog);
    } // setupUi

    void retranslateUi(QDialog *SettingsDialog)
    {
        SettingsDialog->setWindowTitle(tr2i18n("Profile Settings", nullptr));
#if QT_CONFIG(tooltip)
        mediaNeedsChange->setToolTip(tr2i18n("Uncheck if you want to avoid a confirmation dialog to change the medium when a slice was finished", nullptr));
#endif // QT_CONFIG(tooltip)
        mediaNeedsChange->setText(tr2i18n("Target needs media change", nullptr));
        label_4->setText(tr2i18n("Exclude Paths Filter:", nullptr));
        label->setText(tr2i18n("Number of full backups to keep", nullptr));
#if QT_CONFIG(tooltip)
        numBackups->setToolTip(tr2i18n("How many full backups shall be kept in the target directory before older ones will be deleted", nullptr));
#endif // QT_CONFIG(tooltip)
        numBackups->setSpecialValueText(tr2i18n("unlimited", nullptr));
        label_2->setText(tr2i18n("Full Backup Interval", nullptr));
#if QT_CONFIG(tooltip)
        fullBackupInterval->setToolTip(tr2i18n("How often shall a full backup, instead of an incremental one, be done", nullptr));
#endif // QT_CONFIG(tooltip)
        fullBackupInterval->setSpecialValueText(tr2i18n("Every Day", nullptr));
        fullBackupInterval->setSuffix(tr2i18n(" days", nullptr));
        textLabel1->setText(tr2i18n("Archive Prefix:", nullptr));
#if QT_CONFIG(tooltip)
        filter->setToolTip(tr2i18n("Defines wildcards for filenames which will be ignored for backup, separated by a space. E.g.: \"*.ogg *.wav\"", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox2->setTitle(tr2i18n("Maximum Archive Size:", nullptr));
        maxSliceSize->setSpecialValueText(tr2i18n("unlimited", nullptr));
        maxSliceSize->setSuffix(tr2i18n(" MB", nullptr));
        label_3->setText(tr2i18n("Exclude Filename Filter:", nullptr));
#if QT_CONFIG(tooltip)
        dirFilter->setToolTip(tr2i18n("<html><head/><body><p>Defines a list of absolute path patterns which are used to filter complete directories,<br/>e.g. /home/*/.mozilla/*/Cache</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        compressFiles->setToolTip(tr2i18n("Uncheck if you want to avoid compressing files at all", nullptr));
#endif // QT_CONFIG(tooltip)
        compressFiles->setText(tr2i18n("Compress Files", nullptr));
        prefix->setPlaceholderText(tr2i18n("backup", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SettingsDialog: public Ui_SettingsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSDIALOG_H

