/****************************************************************************
** Meta object code from reading C++ file 'Archiver.hxx'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kbackup-26.07.90/src/Archiver.hxx"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Archiver.hxx' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8ArchiverE_t {};
} // unnamed namespace

template <> constexpr inline auto Archiver::qt_create_metaobjectdata<qt_meta_tag_ZN8ArchiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Archiver",
        "inProgress",
        "",
        "runs",
        "logging",
        "warning",
        "targetCapacity",
        "KIO::filesize_t",
        "bytes",
        "sliceProgress",
        "percent",
        "fileProgress",
        "newSlice",
        "totalFilesChanged",
        "totalBytesChanged",
        "elapsedChanged",
        "backupTypeChanged",
        "incremental",
        "cancel",
        "setForceFullBackup",
        "force",
        "slotResult",
        "KJob*",
        "slotListResult",
        "KIO::Job*",
        "KIO::UDSEntryList",
        "receivedOutput",
        "loggingSlot",
        "message",
        "warningSlot",
        "updateElapsed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'inProgress'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'logging'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'warning'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'targetCapacity'
        QtMocHelpers::SignalData<void(KIO::filesize_t)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'sliceProgress'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'fileProgress'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'newSlice'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'totalFilesChanged'
        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'totalBytesChanged'
        QtMocHelpers::SignalData<void(KIO::filesize_t)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'elapsedChanged'
        QtMocHelpers::SignalData<void(const QTime &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QTime, 2 },
        }}),
        // Signal 'backupTypeChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setForceFullBackup'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'setForceFullBackup'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotResult'
        QtMocHelpers::SlotData<void(KJob *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Slot 'slotListResult'
        QtMocHelpers::SlotData<void(KIO::Job *, const KIO::UDSEntryList &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 2 }, { 0x80000000 | 25, 2 },
        }}),
        // Slot 'receivedOutput'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loggingSlot'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'warningSlot'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'updateElapsed'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Archiver, qt_meta_tag_ZN8ArchiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Archiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ArchiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ArchiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8ArchiverE_t>.metaTypes,
    nullptr
} };

void Archiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Archiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->inProgress((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->logging((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->warning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->targetCapacity((*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[1]))); break;
        case 4: _t->sliceProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->fileProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->newSlice((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->totalFilesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->totalBytesChanged((*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[1]))); break;
        case 9: _t->elapsedChanged((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1]))); break;
        case 10: _t->backupTypeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->cancel(); break;
        case 12: _t->setForceFullBackup((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setForceFullBackup(); break;
        case 14: _t->slotResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 15: _t->slotListResult((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::UDSEntryList>>(_a[2]))); break;
        case 16: _t->receivedOutput(); break;
        case 17: _t->loggingSlot((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->warningSlot((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->updateElapsed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Archiver::*)(bool )>(_a, &Archiver::inProgress, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Archiver::*)(const QString & )>(_a, &Archiver::logging, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Archiver::*)(const QString & )>(_a, &Archiver::warning, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Archiver::*)(KIO::filesize_t )>(_a, &Archiver::targetCapacity, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Archiver::*)(int )>(_a, &Archiver::sliceProgress, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Archiver::*)(int )>(_a, &Archiver::fileProgress, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Archiver::*)(int )>(_a, &Archiver::newSlice, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Archiver::*)(int )>(_a, &Archiver::totalFilesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Archiver::*)(KIO::filesize_t )>(_a, &Archiver::totalBytesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Archiver::*)(const QTime & )>(_a, &Archiver::elapsedChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Archiver::*)(bool )>(_a, &Archiver::backupTypeChanged, 10))
            return;
    }
}

const QMetaObject *Archiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Archiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ArchiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Archiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void Archiver::inProgress(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Archiver::logging(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Archiver::warning(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Archiver::targetCapacity(KIO::filesize_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Archiver::sliceProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Archiver::fileProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Archiver::newSlice(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Archiver::totalFilesChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Archiver::totalBytesChanged(KIO::filesize_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Archiver::elapsedChanged(const QTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Archiver::backupTypeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
