/*
(c) 2006
*/

/********************************************************************************
** Form generated from reading UI file 'MainWidgetBase.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWIDGETBASE_H
#define UI_MAINWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_MainWidgetBase
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QPushButton *startButton;
    QPushButton *cancelButton;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLabel *backupType;
    QCheckBox *forceFullBackup;
    QGroupBox *groupBox3;
    QGridLayout *gridLayout1;
    QLabel *textLabel2;
    QLabel *sliceLabel;
    QLabel *sliceNum;
    QProgressBar *progressSlice;
    QLabel *textLabel1;
    QLabel *capacity;
    QPushButton *folder;
    KLineEdit *targetDir;
    QGroupBox *groupBox2;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel4;
    QLabel *totalFiles;
    QLabel *textLabel6;
    QLabel *totalSize;
    QLabel *totalSize_2;
    QSpacerItem *spacer1_2;
    QLabel *textLabel8;
    QLabel *elapsedTime;
    QVBoxLayout *vboxLayout;
    QTextEdit *log;
    QHBoxLayout *hboxLayout2;
    QLabel *textLabel1_2;
    QSpacerItem *spacer2;
    QLabel *fileProgressLabel;
    QProgressBar *fileProgress;
    QTextEdit *warnings;

    void setupUi(QWidget *MainWidgetBase)
    {
        if (MainWidgetBase->objectName().isEmpty())
            MainWidgetBase->setObjectName("MainWidgetBase");
        MainWidgetBase->resize(501, 455);
        gridLayout = new QGridLayout(MainWidgetBase);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        startButton = new QPushButton(MainWidgetBase);
        startButton->setObjectName("startButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(startButton->sizePolicy().hasHeightForWidth());
        startButton->setSizePolicy(sizePolicy);
        startButton->setMinimumSize(QSize(0, 50));
        QFont font;
        font.setPointSize(14);
        startButton->setFont(font);
        startButton->setIconSize(QSize(22, 22));

        hboxLayout->addWidget(startButton);

        cancelButton = new QPushButton(MainWidgetBase);
        cancelButton->setObjectName("cancelButton");
        cancelButton->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cancelButton->sizePolicy().hasHeightForWidth());
        cancelButton->setSizePolicy(sizePolicy1);
        cancelButton->setMinimumSize(QSize(0, 50));
        cancelButton->setIconSize(QSize(22, 22));

        hboxLayout->addWidget(cancelButton);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(MainWidgetBase);
        label->setObjectName("label");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(label);

        backupType = new QLabel(MainWidgetBase);
        backupType->setObjectName("backupType");

        horizontalLayout->addWidget(backupType);

        forceFullBackup = new QCheckBox(MainWidgetBase);
        forceFullBackup->setObjectName("forceFullBackup");

        horizontalLayout->addWidget(forceFullBackup);


        gridLayout->addLayout(horizontalLayout, 1, 0, 1, 1);

        groupBox3 = new QGroupBox(MainWidgetBase);
        groupBox3->setObjectName("groupBox3");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(groupBox3->sizePolicy().hasHeightForWidth());
        groupBox3->setSizePolicy(sizePolicy3);
        gridLayout1 = new QGridLayout(groupBox3);
        gridLayout1->setSpacing(6);
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        gridLayout1->setObjectName("gridLayout1");
        textLabel2 = new QLabel(groupBox3);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        gridLayout1->addWidget(textLabel2, 0, 0, 1, 2);

        sliceLabel = new QLabel(groupBox3);
        sliceLabel->setObjectName("sliceLabel");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(sliceLabel->sizePolicy().hasHeightForWidth());
        sliceLabel->setSizePolicy(sizePolicy4);
        sliceLabel->setWordWrap(false);

        gridLayout1->addWidget(sliceLabel, 1, 0, 1, 1);

        sliceNum = new QLabel(groupBox3);
        sliceNum->setObjectName("sliceNum");
        sizePolicy4.setHeightForWidth(sliceNum->sizePolicy().hasHeightForWidth());
        sliceNum->setSizePolicy(sizePolicy4);
        sliceNum->setMinimumSize(QSize(21, 0));
        sliceNum->setWordWrap(false);

        gridLayout1->addWidget(sliceNum, 1, 1, 1, 1);

        progressSlice = new QProgressBar(groupBox3);
        progressSlice->setObjectName("progressSlice");
        sizePolicy.setHeightForWidth(progressSlice->sizePolicy().hasHeightForWidth());
        progressSlice->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(progressSlice, 1, 2, 1, 1);

        textLabel1 = new QLabel(groupBox3);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        gridLayout1->addWidget(textLabel1, 1, 3, 1, 1);

        capacity = new QLabel(groupBox3);
        capacity->setObjectName("capacity");
        capacity->setMinimumSize(QSize(90, 0));
        capacity->setWordWrap(false);

        gridLayout1->addWidget(capacity, 1, 4, 1, 2);

        folder = new QPushButton(groupBox3);
        folder->setObjectName("folder");
        sizePolicy2.setHeightForWidth(folder->sizePolicy().hasHeightForWidth());
        folder->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(folder, 0, 5, 1, 1);

        targetDir = new KLineEdit(groupBox3);
        targetDir->setObjectName("targetDir");

        gridLayout1->addWidget(targetDir, 0, 2, 1, 3);


        gridLayout->addWidget(groupBox3, 2, 0, 1, 1);

        groupBox2 = new QGroupBox(MainWidgetBase);
        groupBox2->setObjectName("groupBox2");
        sizePolicy3.setHeightForWidth(groupBox2->sizePolicy().hasHeightForWidth());
        groupBox2->setSizePolicy(sizePolicy3);
        hboxLayout1 = new QHBoxLayout(groupBox2);
        hboxLayout1->setSpacing(6);
        hboxLayout1->setContentsMargins(11, 11, 11, 11);
        hboxLayout1->setObjectName("hboxLayout1");
        textLabel4 = new QLabel(groupBox2);
        textLabel4->setObjectName("textLabel4");
        sizePolicy2.setHeightForWidth(textLabel4->sizePolicy().hasHeightForWidth());
        textLabel4->setSizePolicy(sizePolicy2);
        textLabel4->setWordWrap(false);

        hboxLayout1->addWidget(textLabel4);

        totalFiles = new QLabel(groupBox2);
        totalFiles->setObjectName("totalFiles");
        totalFiles->setAlignment(Qt::AlignVCenter);
        totalFiles->setWordWrap(false);

        hboxLayout1->addWidget(totalFiles);

        textLabel6 = new QLabel(groupBox2);
        textLabel6->setObjectName("textLabel6");
        sizePolicy2.setHeightForWidth(textLabel6->sizePolicy().hasHeightForWidth());
        textLabel6->setSizePolicy(sizePolicy2);
        textLabel6->setWordWrap(false);

        hboxLayout1->addWidget(textLabel6);

        totalSize = new QLabel(groupBox2);
        totalSize->setObjectName("totalSize");
        totalSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        totalSize->setWordWrap(false);

        hboxLayout1->addWidget(totalSize);

        totalSize_2 = new QLabel(groupBox2);
        totalSize_2->setObjectName("totalSize_2");
        totalSize_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        totalSize_2->setWordWrap(false);

        hboxLayout1->addWidget(totalSize_2);

        spacer1_2 = new QSpacerItem(10, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacer1_2);

        textLabel8 = new QLabel(groupBox2);
        textLabel8->setObjectName("textLabel8");
        sizePolicy2.setHeightForWidth(textLabel8->sizePolicy().hasHeightForWidth());
        textLabel8->setSizePolicy(sizePolicy2);
        textLabel8->setWordWrap(false);

        hboxLayout1->addWidget(textLabel8);

        elapsedTime = new QLabel(groupBox2);
        elapsedTime->setObjectName("elapsedTime");
        elapsedTime->setWordWrap(false);

        hboxLayout1->addWidget(elapsedTime);


        gridLayout->addWidget(groupBox2, 3, 0, 1, 1);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        log = new QTextEdit(MainWidgetBase);
        log->setObjectName("log");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(2);
        sizePolicy5.setHeightForWidth(log->sizePolicy().hasHeightForWidth());
        log->setSizePolicy(sizePolicy5);
        log->setMinimumSize(QSize(0, 80));
        log->setUndoRedoEnabled(false);
        log->setLineWrapMode(QTextEdit::NoWrap);
        log->setReadOnly(true);

        vboxLayout->addWidget(log);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName("hboxLayout2");
        textLabel1_2 = new QLabel(MainWidgetBase);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setWordWrap(false);

        hboxLayout2->addWidget(textLabel1_2);

        spacer2 = new QSpacerItem(40, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacer2);

        fileProgressLabel = new QLabel(MainWidgetBase);
        fileProgressLabel->setObjectName("fileProgressLabel");
        fileProgressLabel->setWordWrap(false);

        hboxLayout2->addWidget(fileProgressLabel);

        fileProgress = new QProgressBar(MainWidgetBase);
        fileProgress->setObjectName("fileProgress");
        fileProgress->setMaximumSize(QSize(32767, 18));

        hboxLayout2->addWidget(fileProgress);


        vboxLayout->addLayout(hboxLayout2);

        warnings = new QTextEdit(MainWidgetBase);
        warnings->setObjectName("warnings");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(1);
        sizePolicy6.setHeightForWidth(warnings->sizePolicy().hasHeightForWidth());
        warnings->setSizePolicy(sizePolicy6);
        warnings->setMinimumSize(QSize(0, 50));
        QPalette palette;
        QBrush brush(QColor(255, 0, 0, 255));
        brush.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        QBrush brush1(QColor(122, 123, 125, 255));
        brush1.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush1);
        warnings->setPalette(palette);
        warnings->setUndoRedoEnabled(false);
        warnings->setLineWrapMode(QTextEdit::NoWrap);
        warnings->setReadOnly(true);

        vboxLayout->addWidget(warnings);


        gridLayout->addLayout(vboxLayout, 4, 0, 1, 1);


        retranslateUi(MainWidgetBase);

        QMetaObject::connectSlotsByName(MainWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *MainWidgetBase)
    {
        MainWidgetBase->setWindowTitle(tr2i18n("KBackup", nullptr));
        startButton->setText(tr2i18n("Start Backup", nullptr));
        cancelButton->setText(tr2i18n("Cancel Backup", nullptr));
        label->setText(tr2i18n("Next Backup:", nullptr));
        backupType->setText(tr2i18n("TextLabel", nullptr));
        forceFullBackup->setText(tr2i18n("Force Full Backup", nullptr));
        groupBox3->setTitle(tr2i18n("Target", nullptr));
        textLabel2->setText(tr2i18n("Folder:", nullptr));
        sliceLabel->setText(tr2i18n("Medium:", nullptr));
        sliceNum->setText(tr2i18n("1", nullptr));
        textLabel1->setText(tr2i18n("Size:", nullptr));
        capacity->setText(tr2i18n("0 MB", nullptr));
        folder->setText(QString());
        groupBox2->setTitle(tr2i18n("Totals", nullptr));
        textLabel4->setText(tr2i18n("Files:", nullptr));
        totalFiles->setText(tr2i18n("0", nullptr));
        textLabel6->setText(tr2i18n("Size:", nullptr));
        totalSize->setText(tr2i18n("0", nullptr));
        totalSize_2->setText(tr2i18n("MB", nullptr));
        textLabel8->setText(tr2i18n("Duration:", nullptr));
        elapsedTime->setText(tr2i18n("00:00:00", nullptr));
        textLabel1_2->setText(tr2i18n("Warnings:", nullptr));
        fileProgressLabel->setText(tr2i18n("Progress:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MainWidgetBase: public Ui_MainWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MAINWIDGETBASE_H

